local mod = ...


--[[

	Ideally the Lord (player) would be a different type of villager entirely, with different needs and behaviors.
	However I didn't find a way to integrate a new Villager Profile into the game.
	So I'm creating a normal Job for the Lord that can be assigned to any villager.
	They will need to be promoted up to Citizen and renamed if desired.

]]



-- Asset -------------------------------------------------------------------------------------
mod:registerAssetId("models/Authority2.fbx/Prefab/LordMaleFront", "PREFAB_AUTHORITY_LORD_MALE_FRONT")
mod:registerAssetId("models/Authority2.fbx/Prefab/LordMaleHat", "PREFAB_AUTHORITY_LORD_MALE_HAT")

mod:registerAssetId("models/Authority2.fbx/Prefab/LordFemaleBelt", "PREFAB_AUTHORITY_LORD_FEMALE_BELT")
mod:registerAssetId("models/Authority2.fbx/Prefab/LordFemaleFront", "PREFAB_AUTHORITY_LORD_FEMALE_FRONT")
mod:registerAssetId("models/Authority2.fbx/Prefab/LordFemaleHat", "PREFAB_AUTHORITY_LORD_FEMALE_HAT")




-- Job: Lord -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_AUTHORITY_LORD",
	JobName = "JOB_AUTHORITY_LORD_NAME",
	JobDescription = "JOB_AUTHORITY_LORD_DESC",
    IsLockedByDefault = false,
    -- Hidden = true,
    Hidden = false,
	IsDefinitive = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 160.0,
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
        DataType = "CHARACTER_SETUP",
        MaleHatList = {
            "PREFAB_AUTHORITY_LORD_MALE_HAT",
        }, 
        MaleBeltList = {
            "PREFAB_AUTHORITY_BLANK",
        },
        MaleFrontList = {
            "PREFAB_AUTHORITY_LORD_MALE_FRONT",
        },
        FemaleHatList = {
            "PREFAB_AUTHORITY_LORD_FEMALE_HAT",
        }, 
        FemaleBeltList = {
            "PREFAB_AUTHORITY_LORD_FEMALE_BELT",
        },
        FemaleFrontList = {
            "PREFAB_AUTHORITY_LORD_FEMALE_FRONT",
        },
        -- RightHandObject = {
		-- 	DataType = "HAND_OBJECT",
        --     Model = "PREFAB_TOOL_GUARD_SPEAR"
        -- },
		WalkAnimation = "WALKING",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_AUTHORITY_LORD"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_AUTHORITY_LORD"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_AUTHORITY_LORD"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_AUTHORITY_LORD"
    }
})



-- Job: Lady -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "JOB_AUTHORITY_LADY",
	JobName = "JOB_AUTHORITY_LADY_NAME",
	JobDescription = "JOB_AUTHORITY_LADY_DESC",
    IsLockedByDefault = false,
    -- Hidden = true,
    Hidden = false,
	IsDefinitive = true,
	DefaultBehavior = "BEHAVIOR_WORK",
    ProductionDelay = 160.0,
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
        DataType = "CHARACTER_SETUP",
        MaleHatList = {
            "PREFAB_AUTHORITY_LORD_MALE_HAT",
        }, 
        MaleBeltList = {
            "PREFAB_AUTHORITY_BLANK",
        },
        MaleFrontList = {
            "PREFAB_AUTHORITY_LORD_MALE_FRONT",
        },
        FemaleHatList = {
            "PREFAB_AUTHORITY_LORD_FEMALE_HAT",
        }, 
        FemaleBeltList = {
            "PREFAB_AUTHORITY_LORD_FEMALE_BELT",
        },
        FemaleFrontList = {
            "PREFAB_AUTHORITY_LORD_FEMALE_FRONT",
        },
        -- RightHandObject = {
		-- 	DataType = "HAND_OBJECT",
        --     Model = "PREFAB_TOOL_GUARD_SPEAR"
        -- },
		WalkAnimation = "WALKING",
		IdleAnimation = "IDLE"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_AUTHORITY_LADY"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_AUTHORITY_LADY"
    }
})

mod:override({
    Id = "COMMONER",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_AUTHORITY_LADY"
    }
})

mod:override({
    Id = "CITIZEN",
    CompatibleJobList = {
        Action = "APPEND",
        "JOB_AUTHORITY_LADY"
    }
})



-- Building Function: Lord's Chamber -------------------------------------------------------------------------------------
mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "BUILDING_FUNCTION_AUTHORITY_LORD",
	Name = "BUILDING_FUNCTION_AUTHORITY_LORD_NAME",
	HasMaximumInstance = true,
	MaximumInstanceAllowed = 1,
    WorkerCapacity = 1,
    UpkeepPerWorker = {
		{
			Resource = "GOLD_COINS",
			Quantity = 30
		}
	},
    RelatedJob = { 
        Job = "JOB_AUTHORITY_LORD", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
        -- { Resource = "GOLD_COINS", Quantity = 50 },
	},
    ResourceListNeeded = {
        -- { Resource = "GOLD_COINS", Quantity = 5 },
	},
	ResourceProduced = {
        { Resource = "RESOURCE_AUTHORITY", Quantity = 1 },
    }
})



-- Building Function: Lady's Chamber -------------------------------------------------------------------------------------
mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "BUILDING_FUNCTION_AUTHORITY_LADY",
	Name = "BUILDING_FUNCTION_AUTHORITY_LADY_NAME",
	HasMaximumInstance = true,
	MaximumInstanceAllowed = 1,
    WorkerCapacity = 1,
    UpkeepPerWorker = {
		{
			Resource = "GOLD_COINS",
			Quantity = 30
		}
	},
    RelatedJob = { 
        Job = "JOB_AUTHORITY_LADY", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
        -- { Resource = "GOLD_COINS", Quantity = 50 },
	},
    ResourceListNeeded = {
        -- { Resource = "GOLD_COINS", Quantity = 5 },
	},
	ResourceProduced = {
        { Resource = "RESOURCE_AUTHORITY", Quantity = 1 },
    }
})




-- Building Function List: Lord Manor (OVERRIDE) -------------------------------------------------------------------------------------
mod:override({
	Id = "BUILDING_FUNCTION_LIST_LORD_MANOR",
	AssetFunctionList = {
		Action = "APPEND",
		"BUILDING_FUNCTION_AUTHORITY_LORD",
		"BUILDING_FUNCTION_AUTHORITY_LADY",
	}
})




-- -- Villager Status  -------------------------------------------------------------------------------------
-- mod:register({
-- 	DataType = "VILLAGER_STATUS",
-- 	Id = "VILLAGER_STATUS_LORD",
-- 	StatusName = "VILLAGER_STATUS_LORD_NAME",
-- 	Title = "VILLAGER_STATUS_LORD_NAME",
-- 	StatusImportance = 0,
-- 	IsReachedByDefault = true,
-- 	IsManuallyReached = false,
-- 	IsSetNextStatusAutomaticallyWhenNeedsFilled = false,
-- 	CanLowerStatusAssignJob = false,
-- 	AssetVillagerNeedList = nil,
-- 	CompatibleJobList = {
-- 		"JOB_LORD",
-- 	},
-- 	CharacterSetup = {
-- 		DataType = "CHARACTER_SETUP",
--         -- RightHandObject = {
-- 		-- 	DataType = "HAND_OBJECT",
--         --     Model = "PREFAB_TOOL_GUARD_SPEAR"
--         -- },
--         -- FemaleHatList = {
--         --     "PREFAB_SECURITY_CHARACTER_CRIERFEMALE1",
--         -- }, 
--         -- MaleHatList = {
--         --     "PREFAB_SECURITY_CHARACTER_CRIERMALE1",
--         -- }, 
-- 		WalkAnimation = "WALKING",
-- 		IdleAnimation = "IDLE"
-- 	}
-- })



-- -- Villager Portrait  -------------------------------------------------------------------------------------
-- mod:register({
-- 	DataType = "VILLAGER_PORTRAIT",
-- 	Id = "VILLAGER_PORTRAIT_LORD_MALE",
-- 	Portrait = "ILLUSTRATION_ESTATE_CHURCH",
-- 	MaxAge = 40,
-- 	Gender = "MALE"
-- })

-- mod:register({
-- 	DataType = "VILLAGER_PORTRAIT",
-- 	Id = "VILLAGER_PORTRAIT_LORD_FEMALE",
-- 	Portrait = "ILLUSTRATION_ESTATE_CHURCH",
-- 	MaxAge = 40,
-- 	Gender = "FEMALE"
-- })



-- -- Villager Profile  -------------------------------------------------------------------------------------
-- mod:register({
-- 	DataType = "VILLAGER_PROFILE",
-- 	Id = "VILLAGER_PROFILE_LORD",
-- 	Behavior = "BEHAVIOR_GATHER",
-- 	CharacterSetup = nil,
-- 	ProfileFunction = nil,
-- 	Vehicle = nil,
-- 	ProfileName = "VILLAGER_PROFILE_LORD_NAME",
-- 	PortraitList = {
-- 		"VILLAGER_PORTRAIT_LORD_MALE",
-- 		"VILLAGER_PORTRAIT_LORD_FEMALE",
-- 	},
-- 	StatusList = {
-- 		"VILLAGER_STATUS_LORD",
-- 	},
-- 	NavMeshUnlockCategoryList = {
-- 		"NONE",
-- 	},
-- 	IsDefinitive = true,
-- 	CanHaveAPartner = false
-- })